@@ -73,8 +73,25 @@ printf("utime_getr(0, 'm') = %d\n", utime_getr(0, 'm'));
 printf("utime_getr(0, 'd') = %d\n", utime_getr(0, 'd'));
 printf("cutime_getr('y') = %d\n", ctime_getr('y'));
 printf("cutime_getr('m') = %d\n", ctime_getr('m'));
-printf("cutime_getr('d') = %d\n", ctime_getr('d'));
-printf("time_minus(0, 1, 'h') = %d\n", time_minus(0, 1, 'h'));
+taro = safe_memcpy(taro, "abcdefghijklmnopqrstuvwxyz<12345678910>日本語、中国語、韓国語、アラビヤ語、ミャンマー語、サンスクリット語、パーリ語、ヘブライ語、タイ語、タガログ語", 4980);
+taro = safe_base64(taro, 1);
+printf("=============\n");
+printf("%s\n", taro);
+taro = safe_memcpy(taro, "abcdefghijklmnopqrstuvwxyz<12345678910>日本語、中国語、韓国語、アラビヤ語、ミャンマー語、サンスクリット語、パーリ語、ヘブライ語、タイ語、タガログ語", 4980);
+taro = safe_base64(taro, 0);
+printf("=============\n");
+printf("%s\n", taro);
+taro = safe_base64inheader(taro, "Subject: ");
+printf("=============\n");
+printf("%s\n", taro);
+
+taro = safe_memcpy(taro, "jjjjjjjjjjjjj", 1000);
+taro = safe_ujtoj(taro);
+printf("safe_ujtoj(): <%s>\n", taro);
 
 return 0;
 }
+
+
+
+
