@@ -9,6 +9,7 @@ if(0 > ninsyou_check(5)){
    }
 
 
+
 echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
 echo "<HTML>";
 echo "<HEAD>";
@@ -28,33 +29,33 @@ $kcal1 = "bgcolor=#6de051";
 $kcal2 = "bgcolor=#d9c37a";
 
 
-$BNAME = $_GET["BNAME"];
-$BNAME2 = $_GET["BNAME2"];
-$CNAME = $_GET["CNAME"];
-$CNAME2 = $_GET["CNAME2"];
-$MAILTO = $_GET["MAILTO"];
-$MAILCC = $_GET["MAILCC"];
-$MAILSEND = $_GET["MAILSEND"];
-$PLUSTIME = $_GET["PLUSTIME"];
-$STAT = $_GET["STAT"];
-$STARTTIME = $_GET["STARTTIME"];
-$STOPSETTIME = $_GET["STOPSETTIME"];
-$FREE1 = $_GET["FREE1"];
-$UNO = $_GET["UNO"];
+$BNAME = enco($_GET["BNAME"]);
+$BNAME2 = enco($_GET["BNAME2"]);
+$CNAME = enco($_GET["CNAME"]);
+$CNAME2 = enco($_GET["CNAME2"]);
+$MAILTO = enco($_GET["MAILTO"]);
+$MAILCC = enco($_GET["MAILCC"]);
+$MAILSEND = enco($_GET["MAILSEND"]);
+$PLUSTIME = enco($_GET["PLUSTIME"]);
+$STAT = enco($_GET["STAT"]);
+$STARTTIME = enco($_GET["STARTTIME"]);
+$STOPSETTIME = enco($_GET["STOPSETTIME"]);
+$FREE1 = enco($_GET["FREE1"]);
+$UNO = enco($_GET["UNO"]);
 
-$BNAME_CH = $_GET["BNAME_CH"];
-$BNAME2_CH = $_GET["BNAME2_CH"];
-$CNAME_CH = $_GET["CNAME_CH"];
-$CNAME2_CH = $_GET["CNAME2_CH"];
-$MAILTO_CH = $_GET["MAILTO_CH"];
-$MAILCC_CH = $_GET["MAILCC_CH"];
-$MAILSEND_CH = $_GET["MAILSEND_CH"];
-$PLUSTIME_CH = $_GET["PLUSTIME_CH"];
-$STAT_CH = $_GET["STAT_CH"];
-$STARTTIME_CH = $_GET["STARTTIME_CH"];
-$STOPSETTIME_CH = $_GET["STOPSETTIME_CH"];
-$FREE1_CH = $_GET["FREE1_CH"];
-$UNO_CH = $_GET["UNO_CH"];
+$BNAME_CH = enco($_GET["BNAME_CH"]);
+$BNAME2_CH = enco($_GET["BNAME2_CH"]);
+$CNAME_CH = enco($_GET["CNAME_CH"]);
+$CNAME2_CH = enco($_GET["CNAME2_CH"]);
+$MAILTO_CH = enco($_GET["MAILTO_CH"]);
+$MAILCC_CH = enco($_GET["MAILCC_CH"]);
+$MAILSEND_CH = enco($_GET["MAILSEND_CH"]);
+$PLUSTIME_CH = enco($_GET["PLUSTIME_CH"]);
+$STAT_CH = enco($_GET["STAT_CH"]);
+$STARTTIME_CH = enco($_GET["STARTTIME_CH"]);
+$STOPSETTIME_CH = enco($_GET["STOPSETTIME_CH"]);
+$FREE1_CH = enco($_GET["FREE1_CH"]);
+$UNO_CH = enco($_GET["UNO_CH"]);
 
 
 if(0 != strlen($CNAME)){
@@ -235,7 +236,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
+      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
       $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
@@ -243,7 +244,7 @@ if($num > 0){
          }
       $num1 = pg_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -265,7 +266,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($cname_count < $num){
-      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
+      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
       $cname_count++;
       }
    }
@@ -325,18 +326,18 @@ echo "<td $kcal2><font size=1>*</font></td>";
 echo "</tr>"; 
 
 while($s < $num){
-   $YOUNAME = rtrim(pg_fetch_Result($result, $s, youname));
-   $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
-   $BNAME = rtrim(pg_fetch_Result($result, $s, bname));
-   $MAILSEND = rtrim(pg_fetch_Result($result, $s, mailsend));
-   $STAT = rtrim(pg_fetch_Result($result, $s, stat));
-   $PLUSTIME = rtrim(pg_fetch_Result($result, $s, plustime));
-   $STARTTIME = rtrim(pg_fetch_Result($result, $s, starttime));
-   $STOPSETTIME = rtrim(pg_fetch_Result($result, $s, stopsettime));
-   $MAILTO = rtrim(pg_fetch_Result($result, $s, mailto));
-   $MAILCC = rtrim(pg_fetch_Result($result, $s, mailcc));
-   $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
-   $UNO = rtrim(pg_fetch_Result($result, $s, uno));
+   $YOUNAME = enco_rtrim(pg_fetch_Result($result, $s, youname));
+   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+   $BNAME = enco_rtrim(pg_fetch_Result($result, $s, bname));
+   $MAILSEND = enco_rtrim(pg_fetch_Result($result, $s, mailsend));
+   $STAT = enco_rtrim(pg_fetch_Result($result, $s, stat));
+   $PLUSTIME = enco_rtrim(pg_fetch_Result($result, $s, plustime));
+   $STARTTIME = enco_rtrim(pg_fetch_Result($result, $s, starttime));
+   $STOPSETTIME = enco_rtrim(pg_fetch_Result($result, $s, stopsettime));
+   $MAILTO = enco_rtrim(pg_fetch_Result($result, $s, mailto));
+   $MAILCC = enco_rtrim(pg_fetch_Result($result, $s, mailcc));
+   $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
+   $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
 
    $pmode = $acol1;
    $moni = monitor_count($BNAME);
