@@ -54,17 +54,17 @@ echo "<TABLE cellspacing=0 cellpadding=3 nowrap border=1 Bordercolor='$my_bocolo
 // echo "<TABLE  cellspacing=0 cellpadding=3 nowrap border=0 Bordercolor='$my_bocolor' nowrap border=0  WIDTH='90%' height='8%'BGCOLOR='#e6e8fa'>";
 
 
-$BNAME = $_GET["BNAME"];
-$CNAME = $_GET["CNAME"];
-$MAILTO = $_GET["MAILTO"];
-$MAILCC = $_GET["MAILCC"];
-$MAILSEND = $_GET["MAILSEND"];
-$PLUSTIME = $_GET["PLUSTIME"];
-$STAT = $_GET["STAT"];
-$STARTTIME = $_GET["STARTTIME"];
-$STOPSETTIME = $_GET["STOPSETTIME"];
-$FREE1 = $_GET["FREE1"];
-$UNO = $_GET["UNO"];
+$BNAME = enco($_GET["BNAME"]);
+$CNAME = enco($_GET["CNAME"]);
+$MAILTO = enco($_GET["MAILTO"]);
+$MAILCC = enco($_GET["MAILCC"]);
+$MAILSEND = enco($_GET["MAILSEND"]);
+$PLUSTIME = enco($_GET["PLUSTIME"]);
+$STAT = enco($_GET["STAT"]);
+$STARTTIME = enco($_GET["STARTTIME"]);
+$STOPSETTIME = enco($_GET["STOPSETTIME"]);
+$FREE1 = enco($_GET["FREE1"]);
+$UNO = enco($_GET["UNO"]);
 
 
 if(0 >= strlen($STAT)){
@@ -89,18 +89,18 @@ if(0 != strlen($BNAME)){
           echo "֥å¸ߤΤȿǤƤޤ\n";
 //          echo "$select_data\n";
 
-            $YOUNAME = rtrim(pg_fetch_Result($result, $s, youname));
-            $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
-            $BNAME = rtrim(pg_fetch_Result($result, $s, bname));
-            $MAILSEND = rtrim(pg_fetch_Result($result, $s, mailsend));
-            $STAT = rtrim(pg_fetch_Result($result, $s, stat));
-            $PLUSTIME = rtrim(pg_fetch_Result($result, $s, plustime));
-            $STARTTIME = rtrim(pg_fetch_Result($result, $s, starttime));
-            $STOPSETTIME = rtrim(pg_fetch_Result($result, $s, stopsettime));
-            $MAILTO = rtrim(pg_fetch_Result($result, $s, mailto));
-            $MAILCC = rtrim(pg_fetch_Result($result, $s, mailcc));
-            $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
-            $UNO = rtrim(pg_fetch_Result($result, $s, uno));
+            $YOUNAME = enco_rtrim(pg_fetch_Result($result, $s, youname));
+            $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+            $BNAME = enco_rtrim(pg_fetch_Result($result, $s, bname));
+            $MAILSEND = enco_rtrim(pg_fetch_Result($result, $s, mailsend));
+            $STAT = enco_rtrim(pg_fetch_Result($result, $s, stat));
+            $PLUSTIME = enco_rtrim(pg_fetch_Result($result, $s, plustime));
+            $STARTTIME = enco_rtrim(pg_fetch_Result($result, $s, starttime));
+            $STOPSETTIME = enco_rtrim(pg_fetch_Result($result, $s, stopsettime));
+            $MAILTO = enco_rtrim(pg_fetch_Result($result, $s, mailto));
+            $MAILCC = enco_rtrim(pg_fetch_Result($result, $s, mailcc));
+            $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
+            $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
 
 
 
@@ -153,7 +153,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($cname_count < $num){
-      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
+      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
       $cname_count++;
       }
    }
