@@ -26,7 +26,7 @@ print("</table>\n");
 
 $ncol1 = "bgcolor=#f0f0d2";
 $ncol2 = "bgcolor=#d2f0f0";
-$gno = $_GET["KEY"];
+$gno = enco($_GET["KEY"]);
 
 echo "<pre>";
 
@@ -59,30 +59,30 @@ print("\n\n");
 echo "<TABLE border=0  WIDTH=70% height=2% BGCOLOR=$my_bocolor>";
 
 while($s < $num){
-   $CIP = rtrim(pg_fetch_Result($result, $s, cip));
-   $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
-   $MONITOR = rtrim(pg_fetch_Result($result, $s, monitor));
-   $UCT = rtrim(pg_fetch_Result($result, $s, uct));
-   $YE = rtrim(pg_fetch_Result($result, $s, ye));
-   $MO = rtrim(pg_fetch_Result($result, $s, mo));
-   $DA = rtrim(pg_fetch_Result($result, $s, da));
-   $HA = rtrim(pg_fetch_Result($result, $s, ha));
-   $MI = rtrim(pg_fetch_Result($result, $s, mi));
-   $SE = rtrim(pg_fetch_Result($result, $s, se));
-   $SIGN = rtrim(pg_fetch_Result($result, $s, sign));
-   $PROTO = rtrim(pg_fetch_Result($result, $s, proto));
-   $COM = rtrim(pg_fetch_Result($result, $s, com));
-   $CINFO = rtrim(pg_fetch_Result($result, $s, cinfo));
-   $PORT = rtrim(pg_fetch_Result($result, $s, port));
-   $WTIME = rtrim(pg_fetch_Result($result, $s, wtime));
-   $PINFO = rtrim(pg_fetch_Result($result, $s, pinfo));
-   $ERRDATA = rtrim(pg_fetch_Result($result, $s, errdata));
-   $PRINO = rtrim(pg_fetch_Result($result, $s, prino));
-   $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
-   $FREE2 = rtrim(pg_fetch_Result($result, $s, free2));
-   $FREE3 = rtrim(pg_fetch_Result($result, $s, free3));
-   $FREE4 = rtrim(pg_fetch_Result($result, $s, free4));
-   $UNO = rtrim(pg_fetch_Result($result, $s, uno));
+   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+   $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
+   $UCT = enco_rtrim(pg_fetch_Result($result, $s, uct));
+   $YE = enco_rtrim(pg_fetch_Result($result, $s, ye));
+   $MO = enco_rtrim(pg_fetch_Result($result, $s, mo));
+   $DA = enco_rtrim(pg_fetch_Result($result, $s, da));
+   $HA = enco_rtrim(pg_fetch_Result($result, $s, ha));
+   $MI = enco_rtrim(pg_fetch_Result($result, $s, mi));
+   $SE = enco_rtrim(pg_fetch_Result($result, $s, se));
+   $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
+   $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
+   $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
+   $CINFO = enco_rtrim(pg_fetch_Result($result, $s, cinfo));
+   $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
+   $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
+   $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
+   $ERRDATA = enco_rtrim(pg_fetch_Result($result, $s, errdata));
+   $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
+   $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
+   $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
+   $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
+   $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
+   $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
 
    if($PRINO <= 1){
       $pcol = "bgcolor=red";
