@@ -51,7 +51,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
+      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
       $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
@@ -59,7 +59,7 @@ if($num > 0){
          }
       $num1 = pg_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -80,7 +80,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($cname_count < $num){
-      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
+      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
       $cname_count++;
       }
    }
@@ -96,7 +96,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($ip_count < $num){
-      $ip_data[$ip_count] = rtrim(pg_fetch_Result($result, $ip_count, cip));
+      $ip_data[$ip_count] = enco_rtrim(pg_fetch_Result($result, $ip_count, cip));
       $ip_count++;
       }
    }
