@@ -37,7 +37,7 @@ print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolo
 
 
 
-//$youname = $_GET["USER_NAME"];
+//$youname = enco($_GET["USER_NAME"]);
 
 //$auth_user = $_SERVER["PHP_AUTH_USER"];
 //$auth_pw = $_SERVER["PHP_AUTH_PW"];
@@ -65,8 +65,8 @@ print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolo
 //$num = pg_num_rows($result);
 //if($num > 0){
 //   while($count < $num){
-//      $cname = rtrim(pg_fetch_Result($result, $count, cname));
-//      $bname = rtrim(pg_fetch_Result($result, $count, bname));
+//      $cname = enco_rtrim(pg_fetch_Result($result, $count, cname));
+//      $bname = enco_rtrim(pg_fetch_Result($result, $count, bname));
 //      $count++;
 //      }
 //   }
@@ -101,7 +101,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
+      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
       $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
@@ -109,7 +109,7 @@ if($num > 0){
          }
       $num1 = pg_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -130,7 +130,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($cname_count < $num){
-      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
+      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
       $cname_count++;
       }
    }
