@@ -40,40 +40,40 @@ $ncol2 = "bgcolor=#d2f0f0";
 $kcal1 = "bgcolor=#6de051";
 $kcal2 = "bgcolor=#d9c37a";
 
-$cname = $_GET["CNAME"];
-$monitor = $_GET["MONITOR"];
-$cinfo = $_GET["CINFO"];
-$pinfo = $_GET["PINFO"];
-$prino = $_GET["PRINO"];
-$proto = $_GET["PROTO"];
-$cip = $_GET["CIP"];
-$cip2 = $_GET["CIP2"];
-$uno = $_GET["UNO"];
-$come = $_GET["COME"];
-$block = $_GET["FREE4"];
-$block2 = $_GET["FREE42"];
-$com = $_GET["COM"];
-$port = $_GET["PORT"];
-$sign = $_GET["SIGN"];
+$cname = enco($_GET["CNAME"]);
+$monitor = enco($_GET["MONITOR"]);
+$cinfo = enco($_GET["CINFO"]);
+$pinfo = enco($_GET["PINFO"]);
+$prino = enco($_GET["PRINO"]);
+$proto = enco($_GET["PROTO"]);
+$cip = enco($_GET["CIP"]);
+$cip2 = enco($_GET["CIP2"]);
+$uno = enco($_GET["UNO"]);
+$come = enco($_GET["COME"]);
+$block = enco($_GET["FREE4"]);
+$block2 = enco($_GET["FREE42"]);
+$com = enco($_GET["COM"]);
+$port = enco($_GET["PORT"]);
+$sign = enco($_GET["SIGN"]);
 
 
-$cname_ch = $_GET["CNAME_CH"];
-$monitor_ch = $_GET["MONITOR_CH"];
-$cinfo_ch = $_GET["CINFO_CH"];
-$pinfo_ch = $_GET["PINFO_CH"];
-$prino_ch = $_GET["PRINO_CH"];
-$proto_ch = $_GET["PROTO_CH"];
-$cip_ch = $_GET["CIP_CH"];
-$cip2_ch = $_GET["CIP2_CH"];
-$uno_ch = $_GET["UNO_CH"];
-$come_ch = $_GET["COME_CH"];
-$block_ch = $_GET["FREE4_CH"];
-$block2_ch = $_GET["FREE42_CH"];
-$com_ch = $_GET["COM_CH"];
-$port_ch = $_GET["PORT_CH"];
-$sign_ch = $_GET["SIGN_CH"];
+$cname_ch = enco($_GET["CNAME_CH"]);
+$monitor_ch = enco($_GET["MONITOR_CH"]);
+$cinfo_ch = enco($_GET["CINFO_CH"]);
+$pinfo_ch = enco($_GET["PINFO_CH"]);
+$prino_ch = enco($_GET["PRINO_CH"]);
+$proto_ch = enco($_GET["PROTO_CH"]);
+$cip_ch = enco($_GET["CIP_CH"]);
+$cip2_ch = enco($_GET["CIP2_CH"]);
+$uno_ch = enco($_GET["UNO_CH"]);
+$come_ch = enco($_GET["COME_CH"]);
+$block_ch = enco($_GET["FREE4_CH"]);
+$block2_ch = enco($_GET["FREE42_CH"]);
+$com_ch = enco($_GET["COM_CH"]);
+$port_ch = enco($_GET["PORT_CH"]);
+$sign_ch = enco($_GET["SIGN_CH"]);
 
-$csv_ch = $_GET["CSV_CH"];
+$csv_ch = enco($_GET["CSV_CH"]);
 
 $dekinai="Բ";
 
@@ -307,7 +307,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
+      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
       $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
@@ -315,7 +315,7 @@ if($num > 0){
          }
       $num1 = pg_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -388,22 +388,22 @@ if($num > 0){
       }
 
    while($s < $num){
-      $COME = rtrim(pg_fetch_Result($result, $s, come));
-      $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
-      $MONITOR = rtrim(pg_fetch_Result($result, $s, monitor));
-      $SIGN = rtrim(pg_fetch_Result($result, $s, sign));
-      $PROTO = rtrim(pg_fetch_Result($result, $s, proto));
-      $COM = rtrim(pg_fetch_Result($result, $s, com));
-      $CIP = rtrim(pg_fetch_Result($result, $s, cip));
-      $PORT = rtrim(pg_fetch_Result($result, $s, port));
-      $WTIME = rtrim(pg_fetch_Result($result, $s, wtime));
-      $PINFO = rtrim(pg_fetch_Result($result, $s, pinfo));
-      $PRINO = rtrim(pg_fetch_Result($result, $s, prino));
-      $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
-      $FREE2 = rtrim(pg_fetch_Result($result, $s, free2));
-      $FREE3 = rtrim(pg_fetch_Result($result, $s, free3));
-      $FREE4 = rtrim(pg_fetch_Result($result, $s, free4));
-      $UNO = rtrim(pg_fetch_Result($result, $s, uno));
+      $COME = enco_rtrim(pg_fetch_Result($result, $s, come));
+      $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+      $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
+      $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
+      $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
+      $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
+      $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+      $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
+      $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
+      $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
+      $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
+      $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
+      $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
+      $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
+      $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
+      $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
 
 
       if(0 == strcmp($COME, "ON")){
