@@ -7,7 +7,7 @@ if(0 > ninsyou_check(5)){
    exit;
    }
 
-require("./list_file_upload.inc");
+
 
 
 echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
@@ -23,8 +23,8 @@ echo "<pre>";
 
 $ncol1 = "bgcolor=#f0f0d2";
 $ncol2 = "bgcolor=#d2f0f0";
-$uno = $_GET["UNO"];
-$STATUS = $_GET["STATUS"];
+$uno = enco($_GET["UNO"]);
+$STATUS = enco($_GET["STATUS"]);
 
 
 if(0 == strcmp($uno, "NON")){
@@ -69,22 +69,22 @@ print("\n\n");
 echo "<TABLE border=3  WIDTH=50% height=10% BGCOLOR=#e6e8fa>";
 
 while($s < $num){
-   $COME = rtrim(pg_fetch_Result($result, $s, come));
-   $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
-   $MONITOR = rtrim(pg_fetch_Result($result, $s, monitor));
-   $SIGN = rtrim(pg_fetch_Result($result, $s, sign));
-   $PROTO = rtrim(pg_fetch_Result($result, $s, proto));
+   $COME = enco_rtrim(pg_fetch_Result($result, $s, come));
+   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+   $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
+   $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
+   $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
    $COM = pg_fetch_Result($result, $s, com);
-   $CIP = rtrim(pg_fetch_Result($result, $s, cip));
-   $PORT = rtrim(pg_fetch_Result($result, $s, port));
-   $WTIME = rtrim(pg_fetch_Result($result, $s, wtime));
+   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+   $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
+   $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
    $PINFO = pg_fetch_Result($result, $s, pinfo);
-   $PRINO = rtrim(pg_fetch_Result($result, $s, prino));
-   $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
-   $FREE2 = rtrim(pg_fetch_Result($result, $s, free2));
-   $FREE3 = rtrim(pg_fetch_Result($result, $s, free3));
-   $FREE4 = rtrim(pg_fetch_Result($result, $s, free4));
-   $UNO = rtrim(pg_fetch_Result($result, $s, uno));
+   $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
+   $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
+   $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
+   $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
+   $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
+   $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
 
    $s++;
    }
@@ -102,7 +102,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
+      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
       $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
@@ -110,7 +110,7 @@ if($num > 0){
          }
       $num1 = pg_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
