@@ -49,21 +49,21 @@ echo "  <input type='button' value='ƻƥץ졼Ƚ˰ư' onClick=\"window.open('./mo
 echo "</form>";
 
 
-$COME = $_GET["COME"];
-$CNAME = $_GET["CNAME"];
-$MONITOR = $_GET["MONITOR"];
-$SIGN = $_GET["SIGN"];
-$PROTO = $_GET["PROTO"];
-$COM = $_GET["COM"];
-$CIP = $_GET["CIP"];
-$PORT = $_GET["PORT"];
-$WTIME = $_GET["WTIME"];
-$PINFO = $_GET["PINFO"];
-$PRINO = $_GET["PRINO"];
-$FREE1 = $_GET["FREE1"];
-$FREE2 = $_GET["FREE2"];
-$FREE3 = $_GET["FREE3"];
-$FREE4 = $_GET["FREE4"];
+$COME = enco($_GET["COME"]);
+$CNAME = enco($_GET["CNAME"]);
+$MONITOR = enco($_GET["MONITOR"]);
+$SIGN = enco($_GET["SIGN"]);
+$PROTO = enco($_GET["PROTO"]);
+$COM = enco($_GET["COM"]);
+$CIP = enco($_GET["CIP"]);
+$PORT = enco($_GET["PORT"]);
+$WTIME = enco($_GET["WTIME"]);
+$PINFO = enco($_GET["PINFO"]);
+$PRINO = enco($_GET["PRINO"]);
+$FREE1 = enco($_GET["FREE1"]);
+$FREE2 = enco($_GET["FREE2"]);
+$FREE3 = enco($_GET["FREE3"]);
+$FREE4 = enco($_GET["FREE4"]);
 
 
 
@@ -130,7 +130,7 @@ if(0 != strcmp("ASCII", mb_detect_encoding($COM))){
    }
 
 
-//$youname = $_GET["USER_NAME"];
+//$youname = enco($_GET["USER_NAME"]);
 
 //$auth_user = $_SERVER["PHP_AUTH_USER"];
 //$auth_pw = $_SERVER["PHP_AUTH_PW"];
@@ -182,7 +182,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
+      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
       $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
@@ -190,7 +190,7 @@ if($num > 0){
          }
       $num1 = pg_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -211,7 +211,7 @@ if(!$result){
 $num = pg_num_rows($result);
 if($num > 0){
    while($cname_count < $num){
-      $xcname_data[$cname_count] = rtrim(pg_fetch_Result($result, $cname_count, cname));
+      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
       $cname_count++;
       }
    }
