@@ -15,54 +15,54 @@ echo "<META name='GENERATOR' content='AmBuilder'>";
 echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
 
 
-$view_mode = $_GET["VIEW_MODE"];
-$view_name = $_GET["VIEW_NAME"];
+$view_mode = enco($_GET["VIEW_MODE"]);
+$view_name = enco($_GET["VIEW_NAME"]);
 
-$ye = $_GET["YE"];
-$mo = $_GET["MO"];
-$da = $_GET["DA"];
-$ha = $_GET["HA"];
-$mi = $_GET["MI"];
-$monitor = $_GET["MONITOR"];
-$cname = $_GET["CNAME"];
-$cname2 = $_GET["CNAME2"];
-$cinfo = $_GET["CINFO"];
-$cinfo2 = $_GET["CINFO2"];
-$pinfo = $_GET["PINFO"];
-$prino = $_GET["PRINO"];
-$cip = $_GET["CIP"];
-$proto = $_GET["PROTO"];
-$com = $_GET["COM"];
-$port = $_GET["PORT"];
-$free1 = $_GET["FREE1"];
-$free4 = $_GET["FREE4"];
-$free42 = $_GET["FREE42"];
-$errdata = $_GET["ERRDATA"];
+$ye = enco($_GET["YE"]);
+$mo = enco($_GET["MO"]);
+$da = enco($_GET["DA"]);
+$ha = enco($_GET["HA"]);
+$mi = enco($_GET["MI"]);
+$monitor = enco($_GET["MONITOR"]);
+$cname = enco($_GET["CNAME"]);
+$cname2 = enco($_GET["CNAME2"]);
+$cinfo = enco($_GET["CINFO"]);
+$cinfo2 = enco($_GET["CINFO2"]);
+$pinfo = enco($_GET["PINFO"]);
+$prino = enco($_GET["PRINO"]);
+$cip = enco($_GET["CIP"]);
+$proto = enco($_GET["PROTO"]);
+$com = enco($_GET["COM"]);
+$port = enco($_GET["PORT"]);
+$free1 = enco($_GET["FREE1"]);
+$free4 = enco($_GET["FREE4"]);
+$free42 = enco($_GET["FREE42"]);
+$errdata = enco($_GET["ERRDATA"]);
 
-$ye_ch = $_GET["YE_CH"];
-$mo_ch = $_GET["MO_CH"];
-$da_ch = $_GET["DA_CH"];
-$ha_ch = $_GET["HA_CH"];
-$mi_ch = $_GET["MI_CH"];
-$monitor_ch = $_GET["MONITOR_CH"];
-$cname_ch = $_GET["CNAME_CH"];
-$cname2_ch = $_GET["CNAME2_CH"];
-$cinfo_ch = $_GET["CINFO_CH"];
-$cinfo2_ch = $_GET["CINFO2_CH"];
-$pinfo_ch = $_GET["PINFO_CH"];
-$prino_ch = $_GET["PRINO_CH"];
-$cip_ch = $_GET["CIP_CH"];
-$proto_ch = $_GET["PROTO_CH"];
-$com_ch = $_GET["COM_CH"];
-$port_ch = $_GET["PORT_CH"];
-$free1_ch = $_GET["FREE1_CH"];
-$free4_ch = $_GET["FREE4_CH"];
-$free42_ch = $_GET["FREE42_CH"];
-$errdata_ch = $_GET["ERRDATA_CH"];
+$ye_ch = enco($_GET["YE_CH"]);
+$mo_ch = enco($_GET["MO_CH"]);
+$da_ch = enco($_GET["DA_CH"]);
+$ha_ch = enco($_GET["HA_CH"]);
+$mi_ch = enco($_GET["MI_CH"]);
+$monitor_ch = enco($_GET["MONITOR_CH"]);
+$cname_ch = enco($_GET["CNAME_CH"]);
+$cname2_ch = enco($_GET["CNAME2_CH"]);
+$cinfo_ch = enco($_GET["CINFO_CH"]);
+$cinfo2_ch = enco($_GET["CINFO2_CH"]);
+$pinfo_ch = enco($_GET["PINFO_CH"]);
+$prino_ch = enco($_GET["PRINO_CH"]);
+$cip_ch = enco($_GET["CIP_CH"]);
+$proto_ch = enco($_GET["PROTO_CH"]);
+$com_ch = enco($_GET["COM_CH"]);
+$port_ch = enco($_GET["PORT_CH"]);
+$free1_ch = enco($_GET["FREE1_CH"]);
+$free4_ch = enco($_GET["FREE4_CH"]);
+$free42_ch = enco($_GET["FREE42_CH"]);
+$errdata_ch = enco($_GET["ERRDATA_CH"]);
 
-$csv_ch = $_GET["CSV_CH"];
+$csv_ch = enco($_GET["CSV_CH"]);
 
-$start = $_GET["START"];
+$start = enco($_GET["START"]);
 
 
 
@@ -398,30 +398,30 @@ if(0 == strcmp($csv_ch, "on")){
 
    while($s < $num && $s < $stop){
 
-      $CIP = rtrim(pg_fetch_Result($result, $s, cip));
-      $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
-      $MONITOR = rtrim(pg_fetch_Result($result, $s, monitor));
-      $UCT = rtrim(pg_fetch_Result($result, $s, uct));
-      $YE = rtrim(pg_fetch_Result($result, $s, ye));
-      $MO = rtrim(pg_fetch_Result($result, $s, mo));
-      $DA = rtrim(pg_fetch_Result($result, $s, da));
-      $HA = rtrim(pg_fetch_Result($result, $s, ha));
-      $MI = rtrim(pg_fetch_Result($result, $s, mi));
-      $SE = rtrim(pg_fetch_Result($result, $s, se));
-      $SIGN = rtrim(pg_fetch_Result($result, $s, sign));
-      $PROTO = rtrim(pg_fetch_Result($result, $s, proto));
-      $COM = rtrim(pg_fetch_Result($result, $s, com));
-      $CINFO = rtrim(pg_fetch_Result($result, $s, cinfo));
-      $PORT = rtrim(pg_fetch_Result($result, $s, port));
-      $WTIME = rtrim(pg_fetch_Result($result, $s, wtime));
-      $PINFO = rtrim(pg_fetch_Result($result, $s, pinfo));
-      $ERRDATA = rtrim(pg_fetch_Result($result, $s, errdata));
-      $PRINO = rtrim(pg_fetch_Result($result, $s, prino));
-      $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
-      $FREE2 = rtrim(pg_fetch_Result($result, $s, free2));
-      $FREE3 = rtrim(pg_fetch_Result($result, $s, free3));
-      $FREE4 = rtrim(pg_fetch_Result($result, $s, free4));
-      $UNO = rtrim(pg_fetch_Result($result, $s, uno));
+      $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+      $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+      $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
+      $UCT = enco_rtrim(pg_fetch_Result($result, $s, uct));
+      $YE = enco_rtrim(pg_fetch_Result($result, $s, ye));
+      $MO = enco_rtrim(pg_fetch_Result($result, $s, mo));
+      $DA = enco_rtrim(pg_fetch_Result($result, $s, da));
+      $HA = enco_rtrim(pg_fetch_Result($result, $s, ha));
+      $MI = enco_rtrim(pg_fetch_Result($result, $s, mi));
+      $SE = enco_rtrim(pg_fetch_Result($result, $s, se));
+      $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
+      $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
+      $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
+      $CINFO = enco_rtrim(pg_fetch_Result($result, $s, cinfo));
+      $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
+      $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
+      $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
+      $ERRDATA = enco_rtrim(pg_fetch_Result($result, $s, errdata));
+      $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
+      $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
+      $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
+      $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
+      $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
+      $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
 
       $ERR = strtr($ERRDATA, "\n", "||");
       $SS = $s + 1;
@@ -456,30 +456,30 @@ else {
    echo "</tr>";
 
    while($s < $num && $s < $stop){
-      $CIP = rtrim(pg_fetch_Result($result, $s, cip));
-      $CNAME = rtrim(pg_fetch_Result($result, $s, cname));
-      $MONITOR = rtrim(pg_fetch_Result($result, $s, monitor));
-      $UCT = rtrim(pg_fetch_Result($result, $s, uct));
-      $YE = rtrim(pg_fetch_Result($result, $s, ye));
-      $MO = rtrim(pg_fetch_Result($result, $s, mo));
-      $DA = rtrim(pg_fetch_Result($result, $s, da));
-      $HA = rtrim(pg_fetch_Result($result, $s, ha));
-      $MI = rtrim(pg_fetch_Result($result, $s, mi));
-      $SE = rtrim(pg_fetch_Result($result, $s, se));
-      $SIGN = rtrim(pg_fetch_Result($result, $s, sign));
-      $PROTO = rtrim(pg_fetch_Result($result, $s, proto));
-      $COM = rtrim(pg_fetch_Result($result, $s, com));
-      $CINFO = rtrim(pg_fetch_Result($result, $s, cinfo));
-      $PORT = rtrim(pg_fetch_Result($result, $s, port));
-      $WTIME = rtrim(pg_fetch_Result($result, $s, wtime));
-      $PINFO = rtrim(pg_fetch_Result($result, $s, pinfo));
-      $ERRDATA = rtrim(pg_fetch_Result($result, $s, errdata));
-      $PRINO = rtrim(pg_fetch_Result($result, $s, prino));
-      $FREE1 = rtrim(pg_fetch_Result($result, $s, free1));
-      $FREE2 = rtrim(pg_fetch_Result($result, $s, free2));
-      $FREE3 = rtrim(pg_fetch_Result($result, $s, free3));
-      $FREE4 = rtrim(pg_fetch_Result($result, $s, free4));
-      $UNO = rtrim(pg_fetch_Result($result, $s, uno));
+      $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+      $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+      $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
+      $UCT = enco_rtrim(pg_fetch_Result($result, $s, uct));
+      $YE = enco_rtrim(pg_fetch_Result($result, $s, ye));
+      $MO = enco_rtrim(pg_fetch_Result($result, $s, mo));
+      $DA = enco_rtrim(pg_fetch_Result($result, $s, da));
+      $HA = enco_rtrim(pg_fetch_Result($result, $s, ha));
+      $MI = enco_rtrim(pg_fetch_Result($result, $s, mi));
+      $SE = enco_rtrim(pg_fetch_Result($result, $s, se));
+      $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
+      $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
+      $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
+      $CINFO = enco_rtrim(pg_fetch_Result($result, $s, cinfo));
+      $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
+      $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
+      $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
+      $ERRDATA = enco_rtrim(pg_fetch_Result($result, $s, errdata));
+      $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
+      $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
+      $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
+      $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
+      $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
+      $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
 
       if($PRINO <= 1){
          $pcol = "bgcolor=red";
