@@ -1,14 +1,18 @@
 
+
 #include<stdio.h>
 #include<netinet/in.h>
 #include<string.h>
 #include<stdlib.h>
+#include<pthread.h>
 
 #include"sitar.h"
 #include"sitar_scan.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
+
+
 /*
 int scan_snmp(struct scan_buf *);
 */
@@ -20,8 +24,8 @@ int ch_en(char);
 
 
 
-/* 戻り値はエラー文字列 */
-/* 1) OID 2) 戻り値、マロックされたポインター 3) int * ステータス、int * 戻り値用整数、整数の場合は結果の数字 */
+/* 戃Tり倁AぃbゃBッDッV文僅列 */
+/* 1) OID 2) 戃Tり倁A、マッックされたポめAッEゃ\ッV 3) int * ゃPテーゃ\ゃP、int * 戃Tり倁A甃B敃G敁|、整敁|ぃ堃G合は結果ぃ敁|字 */
 /* -------- OID CALC -------- */
 char * cal_oid(char * oid, char * backdata, int * stat, int * ret, char * port, char * host, int *chk, int timeout)
 { 
@@ -233,7 +237,7 @@ else{
    plai = 3;
    }
 
-// 閾値がNOTの場合、戻り値は編集なしで全てそのまま返す。
+// 閃Z倁AがNOTぃ堃G合、戻り倁Aぃb緃B集なしで元BぃそのぃZぃZ返す
 if(0 == memcmp(pd->ch_prot, "NOT", 3) || 0 == memcmp(pd->ch_port, "NON", 3)){
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
    backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_23);
@@ -249,7 +253,7 @@ if(0 == memcmp(pd->ch_prot, "NOT", 3) || 0 == memcmp(pd->ch_port, "NON", 3)){
    }
 
 
-// 閾値がLOGの場合、戻りを数字に戻さず、そのまま返す。
+// 閃Z倁AがLOGぃ堃G合、戻りを敁|字に戃Tさず、そぃぃZぃZ返す
 else if(0 == memcmp(pd->ch_prot, "LOG", 3) || 0 == memcmp(pd->ch_port, "log", 3)){
 
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 0, &chk, pd->timeout);
@@ -265,7 +269,7 @@ else if(0 == memcmp(pd->ch_prot, "LOG", 3) || 0 == memcmp(pd->ch_port, "log", 3)
    }
 
 
-// 閾値の先頭が−の場合
+// 閃Z倁Aぃ先頃が−ぃ堃G
 else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
 
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
@@ -319,9 +323,9 @@ else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
    }
 
 
-// 閾値の先頭が＋の場合
+// 閃Z倁Aぃ先頃がVの堃G
 else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
-   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX); // buf +1 は一文字（＋）飛ばしです。
+   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX); // buf +1 ぃb一文僅VVVvばしです
    if(-1 != ch_int(chhi)){
       if((hi = strtol(chhi, (char **)NULL, 10)) >= 0){
          pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
@@ -372,7 +376,7 @@ else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
    }
 
 
-// 閾値の先頭が！の場合
+// 閃Z倁Aぃ先頃がVの堃G
 else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
@@ -411,7 +415,7 @@ else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
    }
 
 
-// 閾値の先頭が＝の場合
+// 閃Z倁Aぃ先頃がVの堃G
 else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
@@ -450,7 +454,7 @@ else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
    }
 
 
-// それ以外の場合もNOTと同じ処理 但し、間違いを正す
+// それ仁E外の堃G合もNOTぃB同じ凃理 但し、間違いを情v
 else {
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
    backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_13);
@@ -468,7 +472,7 @@ else {
 
 
 
-// テストとログモードの処理
+// テストとッめ|チuッVドの凃
 if(0 == self_memcmp(pd->ch_plai, "4")){
    #ifdef SNMP_DEBUG
    printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%d check_stat=%d\n", pd->ch_plai, pd->check_stat);
@@ -505,8 +509,8 @@ else if(0 == self_memcmp(pd->ch_plai, "13")){
 
 
 
-// check_statの設定 正か逆かで反転する。
-// 監視の正逆の判断 check_stat == 1 はエラー 0は正常
+// check_statぃ訃定 歁vか逆かぃ@反Tuする
+// 盁v視の歁v逆の刁A斃 check_stat == 1 ぃbゃBッDッV 0ぃb歁v布N
 if(ret < 0){
    if(pd->ch_stat[0] == '0'){
       pd->check_stat = 1;
