@@ -127,6 +127,8 @@
         char * scan_filename;       /* active */
         char * conf_filename;       /* active */
         char * stat_filename;       /* active */
+        char * cronfile_filename;   /* active */
+        char * cronlist_filename;   /* active */
         } file;
      struct {
         char * server;              /* active */
@@ -148,6 +150,8 @@
         char * scan_stat;            /* active */
         char * conf_stat;            /* active */
         char * stat_stat;            /* active */
+        char * cronfile_stat;        /* active */
+        char * cronlist_stat;        /* active */
         int life_int;
         int life_los;
         int cancel;
